class afs::service(
  $is_upstream = $afs::params::is_upstream,
) inherits afs::params  {

  # in openafs-1.6, the initscript for OpenAFS split into client &
  # server parts. The CERN OpenAFS version continued to use the old
  # 'afs' init script for the client on SLC5 and SLC6. Need to cope
  # with this.

  $afs_service = $is_upstream ? {
    true => 'openafs-client',
    default  => 'afs',
  }

  $afs_service_hasstatus  = $is_upstream  #i.e upstream has it, we did not have these on SLC5/6.
  $afs_service_hasrestart = $is_upstream

  service { 'openafs-client':  # keep the upstream name as 'generic'
    ensure     => running,
    name       => $afs_service,
    enable     => true,
    hasstatus  => $afs_service_hasstatus,
    pattern    => '\[afsd\]',
    hasrestart => $afs_service_hasrestart,
    require    => [ Class['afs::config','afs::install'],
                    Package['openafs-client'] ],
  }

  # Ensure firewalld service is running and enabled
  service { 'firewalld':
    ensure  => running,
    enable  => true,
    require => Package['firewalld'],
  }
}

